<?php 
/**
 * Plugin Name: Sentry Logger (Matomo Plugin)
 * Plugin URI: http://plugins.matomo.org/SentryLogger
 * Description: Log all Matomo errors to a Sentry server
 * Author: Lukas Winkler
 * Author URI: https://lw1.at
 * Version: 0.3.1
 */
?><?php
/**
 * Piwik - free/libre analytics platform
 *
 * @link http://piwik.org
 * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
 */

namespace Piwik\Plugins\SentryLogger;

use Monolog\Logger;
use Piwik\Config;
use Piwik\Piwik;
use Piwik\Plugins\LanguagesManager\LanguagesManager;
use Piwik\Version;

 
if (defined( 'ABSPATH')
&& function_exists('add_action')) {
    $path = '/matomo/app/core/Plugin.php';
    if (defined('WP_PLUGIN_DIR') && WP_PLUGIN_DIR && file_exists(WP_PLUGIN_DIR . $path)) {
        require_once WP_PLUGIN_DIR . $path;
    } elseif (defined('WPMU_PLUGIN_DIR') && WPMU_PLUGIN_DIR && file_exists(WPMU_PLUGIN_DIR . $path)) {
        require_once WPMU_PLUGIN_DIR . $path;
    } else {
        return;
    }
    add_action('plugins_loaded', function () {
        if (function_exists('matomo_add_plugin')) {
            matomo_add_plugin(__DIR__, __FILE__, true);
        }
    });
}

class SentryLogger extends \Piwik\Plugin
{
    /**
     * @param bool|string $pluginName
     */
    public function __construct($pluginName = false) {
        parent::__construct($pluginName);
        $settings = new SystemSettings();
        $dsn = $settings->DSN->getValue();


        if ($dsn) {
            // Add composer dependencies
            require_once PIWIK_INCLUDE_PATH . '/plugins/SentryLogger/vendor/autoload.php';

            \Sentry\init([
                'dsn' => $dsn,
                'release' => Version::VERSION,
            ]);
            $username = Piwik::getCurrentUserLogin();
            $metadata = [
                "module" => Piwik::getModule(),
                "action" => Piwik::getAction(),
//                "currentPlugin" => Piwik::getCurrentPlugin()->pluginName,
                "language" => LanguagesManager::getLanguageCodeForCurrentUser(),
                "hostname" => Config::getHostname()
            ];
            \Sentry\configureScope(function (\Sentry\State\Scope $scope) use ($metadata, $username): void {
                $scope->setUser([
                    'username' => $username
                ]);
                foreach ($metadata as $key => $value) {
                    $scope->setTag($key, $value);
                }
            });
        }
    }

    /**
     * @see \Piwik\Plugin::registerEvents
     */
    public function registerEvents() {
        return array(
            'AssetManager.getJavaScriptFiles' => 'getJavaScriptFiles',
            'Template.jsGlobalVariables' => 'addJsGlobalVariables',
        );
    }

    public function getJavaScriptFiles(&$jsFiles) {
        $jsFiles[] = 'plugins/SentryLogger/libs/bundle.min.js';
        $jsFiles[] = 'plugins/SentryLogger/javascripts/init.js';
    }

    public function addJsGlobalVariables(&$out) {

        $settings = new SystemSettings();
        $dsn = $settings->browserDSN->getValue();
        $out .= "piwik.sentryDSN = '$dsn';\n";
    }


}
